@@ -242,7 +242,7 @@ static void show_diff_perms(FILE *out, mode_t old, mode_t new)
     putc(':', out);
 
     if (S_ISLNK(new))
-      fputs("sym", out);
+      fputs("sym) ", out);
     else
       fprintf(out, "%o) ", (unsigned int) new & PERM_MASK);
 }
