@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -21,6 +21,18 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<stdarg.h>
+/* support platforms that don't yet conform to C99 */
+#if	HAVE_STDINT_H
+#include	<stdint.h>
+#elif	HAVE_INTTYPES_H
+#include	<inttypes.h>
+#else
+#error No stdint.h or inttypes.h found.
+#endif
+#include	"cdb.h"
+#include	"cdb_make.h"
+#include	"hashtbl.h"
+#include	"integrit.h"
 #include	"elcerror.h"
 #include	"elcerror_p.h"
 #ifdef		ELC_FIND_LEAKS
@@ -41,7 +53,7 @@ void die(char *function, char *fmt, ...)
     vfprintf(stderr, fmt, args);
     fputc('\n', stderr);
     va_end(args);
-    exit(EXIT_FAILURE);
+    exit(INTEGRIT_EXIT_FAILURE);
 }
 
 void warn(char *function, char *fmt, ...)
