@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -111,7 +111,7 @@ inline static int finishdir(wftnode *np, wftnode *head,
 int walk_file_tree(wft_context_t *ctx)
 {
     DIR			*root	 = opendir(ctx->rootname);
-    wftnode		dirs	 = { root, NULL };
+    wftnode		dirs;
     wftnode		*np;
     char		*curr_dirname	 = xstrdup(ctx->rootname);
     char		*path		 = NULL;
@@ -120,6 +120,9 @@ int walk_file_tree(wft_context_t *ctx)
     int			ret, cb_ret;
     int			done	 = 0;
 
+    dirs.dir	 = root;
+    dirs.next	 = NULL;
+
     if (! root)
       return WFT_ERROR;
 
