@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -68,7 +68,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #error No stdint.h or inttypes.h found.
 #endif
 #include	"util.h"
-#include	"memory.h"
+/* #include	"memory.h" */
 #include	"bithelp.h"
 #include	"sha1.h"
 
