@@ -1,6 +1,6 @@
 /*
 hashtbl - a handy and fast, free hash table implementation
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -38,7 +38,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #else
 #error No stdint.h or inttypes.h found.
 #endif
-#include	"errmacs.h"
 #include	"hashtbl.h"
 #include	"hgrow.h"
 #include	"hhash.h"
@@ -77,7 +76,7 @@ static char *h_strndup(const char *orig, size_t len)
     return newstr;
 }
 
-void hashtbl_init(hashtbl_t *h, size_t capacity)
+int hashtbl_init(hashtbl_t *h, size_t capacity)
 {
     int		i;
     hashnode_t	**tbl;
@@ -89,10 +88,12 @@ void hashtbl_init(hashtbl_t *h, size_t capacity)
     h->entries	 = 0;
 
     if (! (tbl = malloc(sizeof(hashnode_t *) * capacity)) )
-      fatal_error("malloc table");
+      return -1; /* fatal_error("malloc table"); */
     for (i = 0; i < capacity; ++i)
       tbl[i]	 = NULL;
     h->tbl	 = tbl;
+
+    return 0;
 }
 
 void hashtbl_destroy(hashtbl_t *h)
@@ -129,25 +130,28 @@ void *hashtbl_lookup(hashtbl_t *h, const char *key, size_t keylen)
  * The caller can use the returned pointer to free the associated
  * memory appropriately.
  */
-void *hashtbl_store(hashtbl_t *h, const char *key, size_t keylen, void *data)
+int hashtbl_store(hashtbl_t *h,
+		  const char *key, size_t keylen,
+		  void *data, void **replaced)
 {
-    void	*replaced	 = NULL;
     hashnode_t	**tbl		 = h->tbl;
     hashnode_t	*np;
     uint32_t	hashval		 = hashtbl_cdb_hash(key, keylen) % h->capacity;
 
+    *replaced	 = NULL;
+
     for (np = tbl[hashval]; np; np = np->next) {
       if (! strcmp(key, np->key)) { /* replace entry with identical key */
-	replaced	 = np->data;
+	*replaced	 = np->data;
 	np->data	 = data;
 	break;
       }
     }
-    if (! replaced) {
+    if (! *replaced) {
       if (! (np = malloc(sizeof(hashnode_t))) )
-	fatal_error("malloc hash table node");
+	return -1; /* fatal_error("malloc hash table node"); */
       if (! (np->key = h_strndup(key, keylen)))
-	fatal_error("duplicating hash key");
+	return -1; /* fatal_error("duplicating hash key"); */
       np->next		 = tbl[hashval];
       tbl[hashval]	 = np;
       np->data		 = data;
@@ -158,7 +162,7 @@ void *hashtbl_store(hashtbl_t *h, const char *key, size_t keylen, void *data)
 	hashtbl_grow(h);
     }
 
-    return replaced;
+    return 0;
 }
 
 inline void hashtbl_node_destroy(hashnode_t *np)
