@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-/* $Header: /cvsroot/integrit/integrit/main.c,v 1.20 2001/07/31 02:40:33 ecashin Exp $ */
+/* $Header: /cvsroot/integrit/integrit/main.c,v 1.25 2002/01/05 17:53:31 ecashin Exp $ */
 #include	<config.h>
 #include	<stdio.h>
 #include	<unistd.h>
@@ -40,15 +40,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	"hashtbl/hashtbl.h"
 #include	"elcwft.h"
 #include	"checkset.h"
-#include	"options.h"
+#include	"integrit.h"
 #include	"rules.h"
 #include	"eachfile.h"
 #include	"missing.h"
-#include	"utilities.h"
 #include	"xml.h"
 #include	"elcerror.h"
 #include	"elcerror_p.h"
-#include	"utilities_p.h"
+#include	"hexprint_p.h"
 #include	"options_p.h"
 #include	"elcwft_p.h"
 #include	"eachfile_p.h"
@@ -58,49 +57,49 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	"leakfind.h"
 #endif
 
-static void open_known_cdb(options *opts)
+static void open_known_cdb(integrit_t *it)
 {
-    int		fd	 = open(opts->knowndbname,
+    int		fd	 = open(it->knowndbname,
 				O_RDONLY | O_NDELAY);
 
     if (fd == -1)
       die(__FUNCTION__, "Error: opening known-state database (%s): %s",
-	  opts->knowndbname, strerror(errno));
-    cdb_init(&opts->knowndb, fd);
+	  it->knowndbname, strerror(errno));
+    cdb_init(&it->knowndb, fd);
 }
 
-static void open_current_cdb(options *opts)
+static void open_current_cdb(integrit_t *it)
 {
     FILE	*newdb	 = NULL; /* get rid of superfluous compiler warning */
     int		fd;
 
-    fd	 = open(opts->currdbname,
+    fd	 = open(it->currdbname,
 		O_TRUNC | O_CREAT | O_WRONLY | O_NDELAY, 0640);
     if ((fd == -1) || ! (newdb = fdopen(fd, "wb")) )
       DIE("opening current-state database");
-    memset(&opts->currdb, 0, sizeof(opts->currdb));
-    if (cdb_make_start(&opts->currdb, newdb) == -1)
+    memset(&it->currdb, 0, sizeof(it->currdb));
+    if (cdb_make_start(&it->currdb, newdb) == -1)
       DIE("start cdb_make");
 }
 
-static void close_current_cdb(options *opts)
+static void close_current_cdb(integrit_t *it)
 {
-    if (cdb_make_finish(&opts->currdb) == -1)
+    if (cdb_make_finish(&it->currdb) == -1)
       DIE("finishing current-state database");
-    (void) fclose(opts->currdb.fout);
+    (void) fclose(it->currdb.fout);
 }    
 
-static void close_known_cdb(options *opts)
+static void close_known_cdb(integrit_t *it)
 {
-    (void) close(opts->knowndb.fd);
-    cdb_free(&opts->knowndb);
+    (void) close(it->knowndb.fd);
+    cdb_free(&it->knowndb);
 }
 
-static void get_currdb_checksum(options *opts, char sumbuf[])
+static void get_currdb_checksum(integrit_t *it, char sumbuf[])
 {
     MD5_CONTEXT	context;
     char	buf[BUFSIZ];
-    char	*fname	 = opts->currdbname;
+    char	*fname	 = it->currdbname;
     long	n;
     int		fd	 = open(fname, O_RDONLY);
 
@@ -124,9 +123,9 @@ static void get_currdb_checksum(options *opts, char sumbuf[])
     /* memcpy(sumbuf, context.buf, MD5_DIGEST_LENGTH); */
 }
 
-static void show_currdb_checksum_abbrev(options *opts, char *sumbuf, size_t n)
+static void show_currdb_checksum_abbrev(integrit_t *it, char *sumbuf, size_t n)
 {
-    char	*fname	 = opts->currdbname;
+    char	*fname	 = it->currdbname;
 
     fputs(PROGNAME ": current-state db md5sum -------------- \n"
 	  PROGNAME ": ", stdout);
@@ -135,10 +134,11 @@ static void show_currdb_checksum_abbrev(options *opts, char *sumbuf, size_t n)
     puts(fname);
 }
 
-static void show_currdb_checksum_xml(options *opts, const char *checksum_type,
+static void show_currdb_checksum_xml(integrit_t *it,
+				     const char *checksum_type,
 				     char *sumbuf, size_t n)
 {
-    char	*fname	 = opts->currdbname;
+    char	*fname	 = it->currdbname;
 
     fprintf(stdout, "<checksum type=\"%s\" file=\"%s\">",
 	    checksum_type, fname);
@@ -149,7 +149,7 @@ static void show_currdb_checksum_xml(options *opts, const char *checksum_type,
 
 int main(int argc, char *argv[])
 {
-    options	opts;
+    integrit_t	it;
     char	newdb_checksum[MD5_DIGEST_LENGTH];
     wft_context_t wftctx	 = { 0, };
     int		ret;
@@ -161,64 +161,66 @@ int main(int argc, char *argv[])
 					 * versions of gc */
 #endif
 
-    options_init(&opts);
-    options_set(&opts, argc, argv);
-    if (opts.output == OUTPUT_XML) {
+    it.exit_status = INTEGRIT_EXIT_NOCHANGE;
+
+    options_init(&it);
+    options_set(&it, argc, argv);
+    if (it.output == OUTPUT_XML) {
       xml_declaration(stdout);
       /* xml_dtd(stdout); */
-      xml_start_report(stdout, &opts);
+      xml_start_report(stdout, &it);
     }
-    options_announce(stdout, &opts);
+    options_announce(stdout, &it);
 
     /* todo: use shared file locking with fcntl */
-    if (opts.do_check)
-      open_known_cdb(&opts);
-    if (opts.do_update)
-      open_current_cdb(&opts);
+    if (it.do_check)
+      open_known_cdb(&it);
+    if (it.do_update)
+      open_current_cdb(&it);
     
-    if (opts.do_check || opts.do_update) {
-      wftctx.rootname	 = opts.root;
+    if (it.do_check || it.do_update) {
+      wftctx.rootname	 = it.root;
       wftctx.callback	 = process_file;
-      wftctx.cb_data	 = &opts;
-      wftctx.options	 = opts.verbose > 0 ? WFT_VERBOSE : 0;
+      wftctx.cb_data	 = &it;
+      wftctx.options	 = it.verbose > 0 ? WFT_VERBOSE : 0;
       if ( (ret = walk_file_tree(&wftctx)) == WFT_ERROR
 	   || ret == WFT_OPENDIR_FAIL)
 	DIE("walk_file_tree");
     }
     
-    if (opts.do_update) {
-      close_current_cdb(&opts);
-      get_currdb_checksum(&opts, newdb_checksum);
+    if (it.do_update) {
+      close_current_cdb(&it);
+      get_currdb_checksum(&it, newdb_checksum);
     }
 
-    if (opts.do_check) {
-      if (opts.do_update)
-	check_for_missing(&opts);	/* only do this after new current cdb
+    if (it.do_check) {
+      if (it.do_update)
+	check_for_missing(&it);	/* only do this after new current cdb
 					   is closed (i.e. cdb_make is done) */
-      else if (opts.verbose > 0)
+      else if (it.verbose > 0)
 	fputs(PROGNAME ": not doing update, so no check for missing files\n",
 	      stderr);
       
-      close_known_cdb(&opts);
+      close_known_cdb(&it);
     }
-    if (opts.do_update) {
-      if (opts.output == OUTPUT_XML)
-	show_currdb_checksum_xml(&opts, "MD5",
+    if (it.do_update) {
+      if (it.output == OUTPUT_XML)
+	show_currdb_checksum_xml(&it, "MD5",
 				 newdb_checksum, sizeof(newdb_checksum));
       else
-	show_currdb_checksum_abbrev(&opts,
+	show_currdb_checksum_abbrev(&it,
 				    newdb_checksum, sizeof(newdb_checksum));
     }
     
-    if (opts.output == OUTPUT_XML) {
+    if (it.output == OUTPUT_XML) {
       XML_END_PRINT(stdout, "report");
       putc('\n', stdout);
     }
 
-    options_destroy(&opts);
+    options_destroy(&it);
 #ifdef		ELC_FIND_LEAKS
     GC_gcollect();		/* find the leaks before exiting */
 #endif
 
-    return 0;
+    return it.exit_status;
 }
