@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2001 Ed Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 /* options.c */
-void options_init(options *o);
-void options_destroy(options *o);
-void options_set(options *o, int argc, char *argv[]);
-void options_announce(FILE *out, options *o);
+void options_init(integrit_t *it);
+void options_destroy(integrit_t *it);
+void options_set(integrit_t *it, int argc, char *argv[]);
+void options_announce(FILE *out, integrit_t *it);
