@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	"xstrdup.h"
 #include	"cdb.h"
 #include	"cdb_make.h"
-#include	"options.h"
+#include	"integrit.h"
 #include	"elcerror.h"
 #include	"rules.h"
 #include	"checkset.h"
@@ -131,14 +131,14 @@ static void rule_override(unsigned long *flags, checkset *rules)
       set_flags_for_switches(flags, rules->switches);
 }
 
-unsigned long rules_for_path(options *opts, const char *path_orig)
+unsigned long rules_for_path(integrit_t *it, const char *path_orig)
 {
     char	*path	 = xstrdup(path_orig);
     char	*p	 = path; /* pointer for running along path */
-    char	*root	 = opts->root;
+    char	*root	 = it->root;
     checkset	*thisrule;	/* for each level of the path */
-    hashtbl_t		*rules	 = opts->ruleset;
-    unsigned long	flags	 = opts->default_flags;
+    hashtbl_t		*rules	 = it->ruleset;
+    unsigned long	flags	 = it->default_flags;
 
     if (strstr(path, root) != path)
       die(__FUNCTION__, "Error: root not found in path (%s)", path);
