@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -33,11 +33,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #error No stdint.h or inttypes.h found.
 #endif
 #include	"gnupg/sha1.h"
-#include	"utilities_p.h"
+#include	"hexprint_p.h"
 #include	"elcerror_p.h"
 #include	"elcerror.h"
 #include	"dbinfo.h"
 #include	"show.h"
+#define		ELC_TIMEBUFSIZ	16 /* "20011215-010101" (with null char) */
+
 
 /* based on show_diff_lines_long in eachfile.c */
 void show_long(FILE *out, char T, long val)
@@ -53,13 +55,12 @@ void show_octal(FILE *out, char T, unsigned long val)
 /* based on show_diff_time from eachfile.c */
 void show_time(FILE *out, char T, time_t val)
 {
-    const int	buf_max	 = 16;	/* 20001212-010101 + null */
-    char	buf[buf_max];
+    char	buf[ELC_TIMEBUFSIZ];
 
     putc(T, out);
     putc('(', out);
 
-    if (! strftime(buf, buf_max, "%Y%m%d-%H%M%S", localtime(&val)) )
+    if (! strftime(buf, ELC_TIMEBUFSIZ, "%Y%m%d-%H%M%S", localtime(&val)) )
       DIE("strftime");
     fputs(buf, out);
 
