@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2001 Ed Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	"cdb.h"
 #include	"cdb_make.h"
 #include	"hashtbl/hashtbl.h"
-#include	"options.h"
+#include	"integrit.h"
 #ifdef		ELC_FIND_LEAKS
 #include	"leakfind.h"
 #endif
@@ -113,9 +113,9 @@ void xml_print(FILE *out, const char *buf)
       xml_putc(out, *buf);
 }
 
-void xml_start_report(FILE *out, const options *o)
+void xml_start_report(FILE *out, const integrit_t *it)
 {
     fprintf(out, "<report date=\"%ld\" integrit_version=\"%s\">\n",
-	    time(NULL), INTEGRIT_VERSION);
+	    (long) time(NULL), INTEGRIT_VERSION);
 }
 
