@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 void xml_declaration(FILE *out);
 void xml_dtd(FILE *out);
-void xml_start_report(FILE *out, const options *o);
+void xml_start_report(FILE *out, const integrit_t *it);
 void xml_start_print(FILE *out, const char *tag);
 void xml_end_print(FILE *out, const char *tag);
 void xml_print(FILE *out, const char *buf);
