@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000, 2001 Ed L. Cashin
+Copyright (C) 2000, 2001, 2002 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,6 +23,18 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	<string.h>
 #include	<stdarg.h>
 #include	<errno.h>
+/* support platforms that don't yet conform to C99 */
+#if	HAVE_STDINT_H
+#include	<stdint.h>
+#elif	HAVE_INTTYPES_H
+#include	<inttypes.h>
+#else
+#error No stdint.h or inttypes.h found.
+#endif
+#include	"cdb.h"
+#include	"cdb_make.h"
+#include	"hashtbl.h"
+#include	"integrit.h"
 #ifdef	ELC_FIND_LEAKS
 #include	"leakfind.h"
 #endif
@@ -34,7 +46,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	fatal_error(s)	do {					\
     fprintf(stderr, PROGNAME ": Error in %s (%s): %s\n",	\
 	    __FUNCTION__, s, strerror(errno));			\
-    exit(EXIT_FAILURE);						\
+    exit(INTEGRIT_EXIT_FAILURE);				\
 } while (0)
 #endif
 
